<template>
  <a-spin :spinning='confirmLoading'>
    <j-form-container :disabled='formDisabled'>
      <a-form-model ref='form' :model='model' :rules='validatorRules' slot='detail'>
        <a-row>
          <a-col :span='24'>
            <a-form-model-item label='批次' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='batchId'>
              <j-search-select-tag placeholder='请选择批次' v-model='model.batchId' :dictOptions='batchOptions' disabled />
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='检验类别' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='testingCat'>
              <j-search-select-tag placeholder='请输入检验类别' v-model='model.testingCat' :dictOptions='catOptions'
                                   disabled />
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='检验类型' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='testingType'>
              <j-search-select-tag placeholder='请输入检验类型' v-model='model.testingType' :dictOptions='typOptions'
                                   disabled />
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='检测员' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='inspector'>
              <j-select-user-by-dep placeholder='请选择检测员' v-model='model.inspector'
                                    :multi='false'></j-select-user-by-dep>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='检测时间' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='inspectTime'>
              <j-date placeholder='请选择检测时间' v-model='model.inspectTime' style='width: 100%' />
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='环境温度' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='temperature'>
              <a-input type='number' v-model='model.temperature' placeholder='请输入环境温度' addonAfter='℃'
                       :precision='1'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='环境湿度' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='humidity'>
              <a-input type='number' v-model='model.humidity' placeholder='请输入环境湿度' addonAfter='%'
                       :precision='1'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='结论' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='conclusion'>
              <a-input v-model='model.conclusion' placeholder='请输入结论'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='质量评分' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='score'>
              <a-rate v-model.number='model.score' @change='rateChange' />
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='过程问题描述' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='problemDesc'>
              <a-input v-model='model.problemDesc' placeholder='请输入过程问题描述'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='补充说明' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='replenish'>
              <a-input v-model='model.replenish' placeholder='请输入补充说明'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='是否复测' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='recheck'>
              <j-switch :tips='["是","否"]' v-model='model.recheck' placeholder='请选择是否复测'></j-switch>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='审核人' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='auditor'>
              <j-select-user-by-dep placeholder='请输入审核人' v-model='model.auditor' :multi='false'></j-select-user-by-dep>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='审核日期' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='auditTime'>
              <j-date placeholder='请选择审核日期' v-model='model.auditTime' style='width: 100%' />
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='备注' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='remark'>
              <a-input v-model='model.remark' placeholder='请输入备注'></a-input>
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </j-form-container>
  </a-spin>
</template>

<script>

import { httpAction, getAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'
import { queryBatchList } from '@api/lims'

export default {
  name: 'LimsBatchResultForm',
  components: {},
  props: {
    //表单禁用
    disabled: {
      type: Boolean,
      default: false,
      required: false
    },
    catOptions: {
      type: Array,
      required: true
    },
    typOptions: {
      type: Array,
      required: true
    }
  },
  data() {
    return {
      model: {
      },
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },
      confirmLoading: false,
      validatorRules: {},
      batchOptions: [],
      url: {
        add: '/lims/testing/result/add',
        edit: '/lims/testing/result/edit',
        queryById: '/lims/testing/result/queryById'
      }
    }
  },
  computed: {
    formDisabled() {
      return this.disabled
    }
  },
  created() {
    //备份model原始值
    this.modelDefault = JSON.parse(JSON.stringify(this.model))
  },
  methods: {
    add() {
      this.edit(this.modelDefault)
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
      this.initDictConfig()
    },
    submitForm() {

      console.info(this.model)
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {

          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            httpurl += this.url.edit
            method = 'put'
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
          })
        }

      })
    },
    rateChange(value) {

    },
    initDictConfig() {
      queryBatchList().then(res => {
        if (res.success) {
          this.batchOptions = []
          res.result.records.forEach(item => {
            this.batchOptions.push({ 'text': item.batchCode, 'value': item.id })
          })
        }
      })

    }
  }
}
</script>